@@ -15,10 +15,10 @@ spec = do
           , SrcLoc {
               srcLocPackage = "main"
             , srcLocModule = "Example"
-            , srcLocFile = "test/Example.hs"
-            , srcLocStartLine = 11
+            , srcLocFile = "test" </> "Example.hs"
+            , srcLocStartLine = 18
             , srcLocStartCol = 7
-            , srcLocEndLine = 11
+            , srcLocEndLine = 18
             , srcLocEndCol = 10
             }
           )
@@ -26,10 +26,10 @@ spec = do
           , SrcLoc {
               srcLocPackage = "main"
             , srcLocModule = "Example"
-            , srcLocFile = "test/Example.hs"
-            , srcLocStartLine = 8
+            , srcLocFile = "test" </> "Example.hs"
+            , srcLocStartLine = 15
             , srcLocStartCol = 8
-            , srcLocEndLine = 8
+            , srcLocEndLine = 15
             , srcLocEndCol = 11
             }
           )
